@@ -1,4 +1,4 @@
-/*  $Id: main-window.cpp,v 1.42 2013/06/28 18:12:03 sarrazip Exp $
+/*  $Id: main-window.cpp,v 1.43 2013/10/29 00:58:40 sarrazip Exp $
     main-window.cpp - Input and conjugation window
 
     verbiste - French conjugation system
@@ -279,9 +279,9 @@ showAbout()
         NULL
     };
 
-    string logoFilename = string(PIXMAPDIR) + "/" + PACKAGE ".png";
+    string logoFilename = string(PIXMAPDIR) + "/" + PACKAGE ".svg";
 
-    GdkPixbuf *logo = gdk_pixbuf_new_from_file(logoFilename.c_str(), NULL);
+    GdkPixbuf *logo = gdk_pixbuf_new_from_file_at_size(logoFilename.c_str(), 48, 48, NULL);
 
     string copyright =
         string("Copyright (C) " COPYRIGHT_YEARS " Pierre Sarrazin <http://sarrazip.com/>\n")
